

% this m-file is used to study how an antialiasing filter may be used to
% remove high frequencies in a signal before it is sampled. We also
% investigate the spectral content of the reconstructed signal with and
% without the antialiasing filter
 
% time increment for the simulation
Deltat = .001;  

% time length for the simulation
tmax = 5;
 

% amplitude and frequency of the desired signal in Hz
ampsig = 1;
fsig = 1; 
 
% amplitude and frequency of the noise signal in Hz
ampnoise = 0.5;
fnoise = 8;
 
 
% sample time and frequency in Hz
T = .09;
f = 1/T;   
 

 

% simulate the response of a ZOH hold to a noisy input signal
sim('noisy_signal');


figure(1)
clf

plot(tout,yout(:,1),'-',tout,yout(:,2),'-',tout,yout(:,3),'-')
axis([0 tmax -2 2])
title(['sample period, T = ',num2str(T),...
      ' sec,  sample frequency, 1/T = ',num2str(f),' Hz'])
 xlabel('time, sec')
legend('signal w/o noise','noisy analog signal','reconstructed signal')





 
 % Antialiasing filter H(jw) = 1/(jwRC + 1)

% Try several values for RC: .001, .01, .1, 1, 10
% Compare the results and explain the differences you see
RC = 100;

% the bode command creates a frequency response plot
% containing the filter evaluated at a number of frequencies
% the frequency vector must be in rad/sec
% we will convert to Hz when plotting

numH = 1;
denH = [RC   1];

omega = logspace(-1,3);
[mag,phase] = bode(numH,denH,omega);

figure(2)
clf

subplot(2,1,1)

semilogx(omega/(2*pi),20*log10(mag))
grid
ylabel('gain, db')
title(['frequency response of lowpass filter, RC = ',num2str(RC)])
subplot(2,1,2)
semilogx(omega/(2*pi),phase)
 xlabel('frequency, Hz')
ylabel('phase, degrees')
grid




figure(3)
clf

sim('filtered_signal');
 
plot(tout,yout(:,1),'-',tout,yout(:,3),'--',tout,yout(:,4),'-')
axis([0 tmax -2 2])
title(['sample period, T = ',num2str(T),...
      ' sec,  sample frequency, 1/T = ',num2str(f),' Hz'])
 xlabel('time, sec')
legend('signal w/o noise','filtered analog signal','reconstructed signal')


