

% this m-file is used to study how an antialiasing filter may be used to
% remove high frequencies in a signal before it is sampled. We also
% investigate the spectral content of the reconstructed signal with and
% without the antialiasing filter
 
% time increment for the simulation
Deltat = .001;  

% time length for the simulation
tmax = 5;
 

% amplitude and frequency of the desired signal in Hz
ampsig = 1;
fsig = 1; 
 
% amplitude and frequency of the noise signal in Hz
ampnoise = 0.5;
fnoise = 8;
 
 
% sample time and frequency in Hz
T = .09;
f = 1/T;   
 

 

% simulate the response of a ZOH hold to a noisy input signal
sim('noisy_signal');




 
 % Antialiasing filter H(jw) = 1/(jwRC + 1)

% Try several values for RC: .001, .01, .1, 1, 10
% Compare the results and explain the differences you see
RC = .2;

% the bode command creates a frequency response plot
% containing the filter evaluated at a number of frequencies
% the frequency vector must be in rad/sec
% we will convert to Hz when plotting

numH = 1;
denH = [RC   1];

 


sim('filtered_signal');
 
 

figure(1)
clf

% take the approximate Fourier transform using the Kamen-Heck
% m-file contfft.m
[noisy_signal_fft,w1] = contfft(yout(:,2),Deltat);    % noisy sinusiod
[filtered_signal_fft,w2] = contfft(yout(:,3),Deltat);    % filtered sinusiod
[ZOH_output_fft,w3] = contfft(yout(:,4),Deltat);   % output of ZOH
[signal_fft,w4] = contfft(yout(:,1),Deltat);   % signal with no noise
 
 subplot(3,1,1)
 plot(w1/2/pi,abs(noisy_signal_fft),'b-',-w1/2/pi,abs(noisy_signal_fft),'b-')
 title('spectral analysis of antialias filtering')
 legend('noisy signal')
 axis([-20 20 0 2])
 subplot(3,1,2)
 plot(w2/2/pi,abs(filtered_signal_fft),'b-',-w2/2/pi,abs(filtered_signal_fft),'b-')
 legend('filtered signal')
 axis([-20 20 0 2])
 subplot(3,1,3)
 plot(w3/2/pi,abs(ZOH_output_fft),'b-',-w3/2/pi,abs(ZOH_output_fft),'b-')
 axis([-20 20 0 2])
 legend('ZOH output')
 xlabel('frequency, Hz')
 
 
 
 % just for fun, let's do a spectral analysis of the sampled and reconstructed signal
 % WITHOUT the antialiasing filter.....
 
 
 
sim('noisy_signal');


% take the approximate Fourier transform using the Kamen-Heck
% m-file contfft.m
[noisy_signal_fft,w1] = contfft(yout(:,2),Deltat);    % noisy sinusiod
[ZOH_output_fft,w3] = contfft(yout(:,3),Deltat);   % output of ZOH
[signal_fft,w4] = contfft(yout(:,1),Deltat);   % signal with no noise



figure(2)
clf

 
 subplot(2,1,1)
 plot(w1/2/pi,abs(noisy_signal_fft),'b-',-w1/2/pi,abs(noisy_signal_fft),'b-')
 title('spectral analysis without antialias filtering')
 legend('noisy signal')
 axis([-20 20 0 2])
 subplot(2,1,2)
 plot(w3/2/pi,abs(ZOH_output_fft),'b-',-w3/2/pi,abs(ZOH_output_fft),'b-')
 axis([-20 20 0 2])
 legend('ZOH output')
 xlabel('frequency, Hz')
%  
%  subplot(2,1,1)
%  plot(w1/2/pi,abs(x_ft),'b-',-w1/2/pi,abs(x_ft),'b-')
%  title('spectral analysis without antialias filtering')
%  legend('noisy signal')
%  axis([-20 20 0 2])
% 
%  subplot(2,1,2)
%  plot(w3/2/pi,abs(yout2_ft),'b-',-w3/2/pi,abs(yout2_ft),'b-')
%  axis([-20 20 0 2])
%  legend('ZOH output')
%  xlabel('frequency, Hz')
%  